@@ -3,11 +3,10 @@ from IPython.display import display, clear_output
 import ipywidgets as widgets
 import pandas as pd
 import ase
+import numpy as np
 
 from clease_gui.base_dashboard import BaseDashboard
-from clease_gui.status_bar import update_statusbar
 from clease_gui import register_logger
-import clease_gui.utils as utils
 
 __all__ = ["DBViewerDashboard"]
 
@@ -37,11 +36,11 @@ class DBViewerDashboard(BaseDashboard):
             children=[self.selection_parameters_widget, selection_help_label]
         )
 
-        self.draw_selection_button = widgets.Button(description="Open in ASE GUI")
-        self.draw_selection_button.on_click(self._on_draw_selection_click)
+        self.draw_selection_button = self.make_event_button(
+            self._draw_selection, description="Open in ASE GUI"
+        )
 
-        self.print_db_button = widgets.Button(description="Show DB content")
-        self.print_db_button.on_click(self._on_print_db)
+        self.print_db_button = self.make_event_button(self._print_db, description="Show DB content")
 
         # Output for displaying the ASE database as a pandas DF
         self.db_content_out = widgets.Output(
@@ -51,22 +50,41 @@ class DBViewerDashboard(BaseDashboard):
                 height="350px",
             )
         )
+        self.max_rows_widget = widgets.BoundedIntText(
+            value=50,
+            min=0,
+            max=99999,
+            description="Rows:",
+        )
+        self.max_rows_help = widgets.Label(
+            "Maximum number of rows to display in the table (0 for unlimited)."
+        )
+        self.count_rows_btn = self.make_event_button(
+            self._on_count_rows_click, description="Count Selection"
+        )
+        self.count_label = widgets.Label(value=None)
 
-    @update_statusbar
-    @utils.disable_cls_widget("print_db_button")
-    def _on_print_db(self, b):
-        with self.event_context(logger=logger):
-            self._print_db()
+    def _on_count_rows_click(self):
+        n_rows = self._count_rows()
+        self.count_label.value = f"Number of rows: {n_rows}"
+        logger.info("Number of rows with selection: %d", n_rows)
+
+    def _count_rows(self):
+        con = self.get_connection()
+        selection = self.get_selection_parameters()
+        return con.count(selection=selection)
 
     def _print_db(self):
         db_name = str(self.db_name)
-        selection = self.selection_parameters_widget.value
+        selection = self.get_selection_parameters()
         con = self.get_connection()
+
+        tot = self._count_rows()
         out = self.db_content_out
-        logger.info("Querying database %s", db_name)
+        logger.info("Querying database %s for %d entries", db_name, tot)
 
         rows = con.select(selection)
-        df = ase_db_rows_to_df(rows)
+        df = ase_db_rows_to_df(rows, nmax=self.max_rows_widget.value)
         with out:
             clear_output(wait=True)
             with pd.option_context("display.max_rows", None, "display.max_columns", None):
@@ -78,14 +96,18 @@ class DBViewerDashboard(BaseDashboard):
     def display(self):
         buttons = widgets.HBox(
             children=[
+                self.count_rows_btn,
                 self.print_db_button,
                 self.draw_selection_button,
             ]
         )
+        rows_box = widgets.HBox(children=[self.max_rows_widget, self.max_rows_help])
         display(
             self.db_select_box,
             self.selection_box,
+            rows_box,
             buttons,
+            self.count_label,
             self.db_content_out,
         )
 
@@ -116,12 +138,6 @@ class DBViewerDashboard(BaseDashboard):
 
         return [row.toatoms() for row in con.select(selection=selection)]
 
-    @update_statusbar
-    @utils.disable_cls_widget("draw_selection_button")
-    def _on_draw_selection_click(self, b) -> None:
-        with self.event_context(logger=logger):
-            self._draw_selection()
-
     def _draw_selection(self) -> None:
         from ase.visualize import view
 
@@ -135,9 +151,9 @@ class DBViewerDashboard(BaseDashboard):
         view(images)
 
 
-def ase_db_rows_to_df(rows) -> pd.DataFrame:
+def ase_db_rows_to_df(rows, nmax=0) -> pd.DataFrame:
     """Convert an ASE database into a pandas data frame"""
-    rows = list(rows)
+    # rows = list(rows)
     base_keys = [
         "id",
         "formula",
@@ -150,31 +166,28 @@ def ase_db_rows_to_df(rows) -> pd.DataFrame:
         "mass",
     ]
 
-    # Grab all extra keys in the key_value_pairs
-    extra_keys = []
-    for row in rows:
-        keys = row.key_value_pairs.keys()
-        for key in keys:
-            if key not in extra_keys:
-                extra_keys.append(key)
-
-    all_keys = base_keys + extra_keys
-    # Now populate the data
+    logger.debug("Reading data from database.")
     rows_list = []
-    for row in rows:
+    for ii, row in enumerate(rows):
+        if nmax > 0 and ii > nmax:
+            break
         data = {}
         for key in base_keys:
-            try:
-                value = getattr(row, key)
-            except AttributeError:
-                value = None
-            data[key] = _formatter(key, value)
-        kvp_dct = row.key_value_pairs
-        for key in extra_keys:
-            value = kvp_dct.get(key, None)
-            data[key] = _formatter(key, value)
+            data[key] = getattr(row, key, None)
+        kvp = row.key_value_pairs
+        data.update(**kvp)
         rows_list.append(data)
-    return pd.DataFrame(rows_list, columns=all_keys)
+
+    logger.debug("Parsing keys...")
+
+    # Get all keys, ensure base keys are sorted in their order
+    all_keys = list(base_keys)
+    all_keys_set = {key for data in rows_list for key in data}
+    for key in all_keys_set:
+        if key not in all_keys:
+            all_keys.append(key)
+    logger.debug("Constructing pandas dataframe.")
+    return pd.DataFrame(rows_list, columns=all_keys).replace({np.nan: None})
 
 
 def _formatter(key, value):
