@@ -5,6 +5,7 @@ import numpy as np
 from clease.settings import ClusterExpansionSettings
 from clease_gui import utils
 import clease_gui as gui
+from clease_gui.app_data import Notification
 from clease_gui.base_dashboard import BaseDashboard
 from clease_gui.status_bar import update_statusbar
 
@@ -44,6 +45,13 @@ class CESettingsDashboard(BaseDashboard):
         self.update_settings_btn = utils.make_clickable_button(
             self._on_update_settings_click, description="Update Settings"
         )
+        self.app_data.subscribe(self.KEYS.SETTINGS, self._enable_settings_button)
+
+    def _enable_settings_button(self, change: Notification):
+        if change.key == self.KEYS.SETTINGS:
+            # Enable button depending if we have a settings
+            is_disabled = change.new_value is None
+            self.update_settings_btn.disabled = is_disabled
 
     @update_statusbar
     @utils.disable_cls_widget("update_settings_btn")
