@@ -6,10 +6,11 @@ from IPython.display import display, clear_output
 import ipywidgets as widgets
 
 import clease
-from clease.settings import CEBulk, CECrystal
+from clease.settings import CEBulk, CECrystal, ClusterExpansionSettings
 from clease.corr_func import CorrFunction
 
 from clease_gui import register_logger, utils
+from clease_gui.app_data import Notification
 from clease_gui.base_dashboard import BaseDashboard
 from clease_gui.status_bar import update_statusbar
 from . import (
@@ -76,8 +77,10 @@ class SettingsMakerDashboard(BaseDashboard):
         )
 
         self.load_settings_fname = widgets.Text(description="Filename:", value="settings.json")
-        self.load_settings_btn = utils.make_clickable_button(
-            self._on_load_settings_click, description="Load settings"
+        self.load_settings_btn = self.make_event_button(
+            self._on_load_settings_click,
+            description="Load settings",
+            pass_button_event=True,
         )
 
         self.load_settings_box = widgets.HBox(
@@ -105,6 +108,8 @@ class SettingsMakerDashboard(BaseDashboard):
         self.reconfigure_progress = widgets.IntProgress()
         self.reconfigure_progress_label = widgets.Label()
 
+        self.app_data.subscribe(self.KEYS.SETTINGS, self._on_settings_change)
+
     @update_statusbar
     @utils.disable_cls_widget("reconfig_db_button")
     def _on_reconfig_click(self, b):
@@ -123,7 +128,7 @@ class SettingsMakerDashboard(BaseDashboard):
         self.reconfigure_progress_label.value = "Starting..."
         t_start = time.perf_counter()
         for row_id, count, total in cf.iter_reconfigure_db_entries():
-            dt = timedelta(seconds=round(time.perf_counter() - t_start))
+            dt = timedelta(seconds=int(time.perf_counter() - t_start))
             msg = f"{count}/{total}, ID: {row_id}. Runtime: {dt}"
             self.reconfigure_progress.value = count
             self.reconfigure_progress.max = total
@@ -237,16 +242,19 @@ class SettingsMakerDashboard(BaseDashboard):
     def get_load_settings_fname(self):
         return self.app_data[self.KEYS.CWD] / self.load_settings_fname.value
 
-    @update_statusbar
-    @utils.disable_cls_widget("load_settings_btn")
     def _on_load_settings_click(self, b):
-        with self.event_context(logger=logger):
-            fname = self.get_load_settings_fname()
-            logger.info("Loading settings from file: %s", str(fname))
-            self.load_settings(fname)
-            logger.info("Load successful.")
+        fname = self.get_load_settings_fname()
+        logger.info("Loading settings from file: %s", str(fname))
+        self.load_settings(fname)
+        logger.info("Load successful.")
 
-    def set_settings_widget_states(self, settings):
+    def _on_settings_change(self, notification: Notification):
+        assert notification.key == self.KEYS.SETTINGS
+        new_val = notification.new_value
+        if new_val is not None:
+            self.set_settings_widget_states(new_val)
+
+    def set_settings_widget_states(self, settings: ClusterExpansionSettings) -> None:
         """Set the widget states from a new settings object"""
         conc = settings.concentration
         self._conc_dashboard.set_widgets_from_load(conc)
